from setuptools import setup

setup(name='dist_kanishka',
      version='0.3',
      description='Gaussian and Binomial distributions',
      readme = "README.md",
      license = "LICENSE",
      packages=['dist_kanishka'],
      author = 'Kanishka Dandeniya',
      author_email = 'kanishka.d@eng.pdn.ac.lk',
      zip_safe=False)
